@@ -57,6 +57,8 @@ class ComponentAssembly:
         int, element.DispBeamColumn]) = field(init=False)
     zerolength_elements: (collections.CollectionWithConnectivity[
         int, element.ZeroLength]) = field(init=False)
+    twonodelink_elements: (collections.CollectionWithConnectivity[
+        int, element.TwoNodeLink]) = field(init=False)
 
     def __post_init__(self):
         self.external_nodes = collections.NodeCollection(self)
@@ -66,6 +68,8 @@ class ComponentAssembly:
         self.disp_beamcolumn_elements = \
             collections.CollectionWithConnectivity(self)
         self.zerolength_elements = collections.CollectionWithConnectivity(self)
+        self.twonodelink_elements = (collections
+                                     .CollectionWithConnectivity(self))
 
     def __srepr__(self):
         """
@@ -81,9 +85,6 @@ class ComponentAssembly:
         res += 'External Nodes\n'
         for node in self.external_nodes.values():
             res += f'  {node.uid}, {node.coords}'
-        res += 'Internal Nodes\n'
-        for node in self.internal_nodes.values():
-            res += f'  {node.uid}, {node.coords}'
         return res
 
     def dict_of_elastic_beamcolumn_elements(self):
@@ -138,7 +139,7 @@ class ComponentAssembly:
         """
         Returns the connectivity of all elements. Elements are
         connected to external nodes. Each component assembly can be
-        represented by a typle of node uids of its connected nodes in
+        represented by a tuple of node uids of its connected nodes in
         ascending order. This method returns a dictionary having these
         tuples as keys, and the associated components as values.
         """
